# Find more information on writing tests for each extension in the links provided:

## Core
Extension to run scripts to validate settings/logs, etc

More docs: [Extension details](plugins/core.md)

## Ansible
Extension to run ansible playbooks as check source

More docs: [Extension details](plugins/ansible.md)

## Metadata
Extension to run scripts to gather metadata

More docs: [Extension details](plugins/metadata.md)

## Faraday
Extension to compare positive/negative affinities files across sosreports

More docs: [Extension details](plugins/faraday.md)

## Winston

Extension for getting metadata out of file contents

More docs: [Extension details](plugins/winston.md)
